@@ -235,6 +235,14 @@ void app_show_controls (Application *app)
         gtk_widget_show_all (app->video_stop);
         if (app->show_playlist) {
             gtk_widget_show (app->toolbar_area);
+            app->in_ui_update = true;
+            gtk_toggle_tool_button_set_active (
+                    GTK_TOGGLE_TOOL_BUTTON (app->aspects_toggle),
+                    app->aspects_ignored);
+            gtk_toggle_tool_button_set_active (
+                    GTK_TOGGLE_TOOL_BUTTON (app->panzoom_toggle),
+                    app->zoom_enabled);
+            app->in_ui_update = false;
             gtk_widget_show_all (app->zoom_box);
         }
     }
@@ -245,7 +253,7 @@ static void _appShowTitle (Application *app)
     GValue icon = { 0 , };
     GValue text = { 0 , };
     if (playlist_selected (app, &icon, &text)) {
-        GdkPixbuf *pix = (GdkPixbuf *) g_value_get_object (&icon);
+        /*GdkPixbuf *pix = (GdkPixbuf *) g_value_get_object (&icon);*/
         const gchar *val = g_value_get_string (&text);
         GtkWidget *img = NULL;
         /*if (pix)
@@ -286,11 +294,11 @@ void app_selection_changed (Application *app)
     }
 }
 
-static void _appShowPlaylistNav (GtkButton * button, Application *app)
+/*static void _appShowPlaylistNav (GtkButton * button, Application *app)
 {
     app_show_controls (app);
     _appShowTitle (app);
-}
+}*/
 
 static void callback_file_open (GtkButton * button, Application * app) {
     gchar *filename = NULL;
@@ -598,7 +606,6 @@ int main (int argc, char* argv[]) {
     PangoFontDescription *pfd;
     Application *app;
     GtkWidget *video_stop;
-    GtkWidget *aspects_toggle;
     GtkWidget *info_box;
     GtkWidget *info_align;
     GtkWidget *zoombox;
@@ -679,16 +686,22 @@ int main (int argc, char* argv[]) {
 
     video_stop = GTK_WIDGET (gtk_tool_button_new (gtk_image_new_from_icon_name(
                     "general_close", HILDON_ICON_SIZE_TOOLBAR), NULL));
-    aspects_toggle = GTK_WIDGET(gtk_tool_button_new(gtk_image_new_from_icon_name(
-                    "camera_video_resolution_wide_screen",
-                    HILDON_ICON_SIZE_TOOLBAR), NULL));
-    app->panzoom_toggle = GTK_WIDGET(
-            gtk_tool_button_new(gtk_image_new_from_icon_name( "general_add",
-                    HILDON_ICON_SIZE_TOOLBAR), NULL));
+    app->aspects_toggle = GTK_WIDGET (gtk_toggle_tool_button_new ());
+    gtk_tool_button_set_icon_widget (
+            GTK_TOOL_BUTTON (app->aspects_toggle),
+            gtk_image_new_from_icon_name (
+                "camera_video_resolution_wide_screen",
+                HILDON_ICON_SIZE_TOOLBAR));
+    app->panzoom_toggle = GTK_WIDGET (gtk_toggle_tool_button_new ());
+    gtk_tool_button_set_icon_widget (
+            GTK_TOOL_BUTTON (app->panzoom_toggle),
+            gtk_image_new_from_icon_name (
+                "general_add",
+                HILDON_ICON_SIZE_TOOLBAR));
 
     g_signal_connect (G_OBJECT (video_stop), "clicked",
             G_CALLBACK (cb_playlist_stop), app->control);
-    g_signal_connect (G_OBJECT (aspects_toggle), "clicked",
+    g_signal_connect (G_OBJECT (app->aspects_toggle), "clicked",
             G_CALLBACK (cb_aspects_toggle), app->control);
     g_signal_connect (G_OBJECT (app->panzoom_toggle), "clicked",
             G_CALLBACK (cb_panzoom_toggle), app->control);
@@ -745,7 +758,7 @@ int main (int argc, char* argv[]) {
     g_object_ref (app->html_viewport);
     gtk_container_add (GTK_CONTAINER (app->video_stop), video_stop);
     gtk_container_add (GTK_CONTAINER (app->zoom_box), zoombox);
-    gtk_container_add (GTK_CONTAINER (zoombox), aspects_toggle);
+    gtk_container_add (GTK_CONTAINER (zoombox), app->aspects_toggle);
     gtk_container_add (GTK_CONTAINER (zoombox), app->panzoom_toggle);
 
     gtk_fixed_put (GTK_FIXED (app->window_area), app->view_area, 0, 0);
