@@ -483,6 +483,7 @@ void Control::stop (bool keep_fullscreen) {
         setCurrent (0L);
     }
     VIEWAREA(m_app)->reset ();
+    m_app->aspects_ignored = false;
     app_set_playing (m_app, NOT_PLAYING);
 
     if (current_generator && current_generator->active ()) {
@@ -553,8 +554,7 @@ void Control::openDocument (NodePtr doc, NodePtr cur) {
     doc->document()->notify_listener = this;
     playlist_data->document = doc;
     playlist_data->current = cur ? cur : doc;
-    cur_url = doc->document ()->caption ();
-    app_set_title ((const char *) cur_url, m_app);
+    app_set_title ((const char *) doc->document ()->caption (), m_app);
     back_request = cur;
     g_timeout_add (0, playSchedule, static_cast <void *> (this));
     updatePlaylistView ();
@@ -864,6 +864,11 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
     debugLog () << "Process stateChanged " << statemap [(int)os] << " -> " << statemap [(int)ns] << endl;
     if (!m_process) // destructing
         return;
+
+    if (os < Process::Buffering && ns >= Process::Buffering)
+        // maybe add a notification about process launch instead
+        m_app->zoom_enabled = false;
+
     if (!mrl && ns > Process::Ready) {
         p->stop (); // reschedule to the NotRunning state
     } else if (ns == Process::NotRunning) {
@@ -1193,15 +1198,21 @@ void cb_playlist_stop (GtkButton * button, void *p) {
 void cb_aspects_toggle (GtkButton * button, void *p)
 {
     Control *ctr = (Control *)p;
-    ctr->viewArea()->toggleUseAspects ();
-    ctr->updateViewAreaSizes ();
+    if (!ctr->m_app->in_ui_update) {
+        ctr->m_app->aspects_ignored = !ctr->m_app->aspects_ignored;
+        ctr->viewArea()->toggleUseAspects ();
+        ctr->updateViewAreaSizes ();
+    }
 }
 
 void cb_panzoom_toggle (GtkButton * button, void *p)
 {
     Control *ctr = (Control *)p;
-    if (ctr->process ())
-        ctr->process ()->toggleScale ();
+    if (!ctr->m_app->in_ui_update) {
+        ctr->m_app->zoom_enabled = !ctr->m_app->zoom_enabled;
+        if (ctr->process ())
+            ctr->process ()->toggleScale ();
+    }
 }
 
 void cb_playlist_save (GtkButton * button, void *p) {
@@ -1265,7 +1276,6 @@ void openFile (Application * app, const gchar * path) {
     if (pd->document)
         pd->document->document()->dispose ();
     pd->document = new SourceDocument (CONTROL(app), String (path));
-    CONTROL(app)->cur_url = path;
     g_timeout_add (0, playSchedule, static_cast <void *> (CONTROL(app)));
     CONTROL(app)->updatePlaylistView (true);
 }
@@ -1345,7 +1355,6 @@ void newFile (Application * app) {
     }
     pd->document = new SourceDocument (CONTROL(app), String ());
     CONTROL(app)->updatePlaylistView (true);
-    CONTROL(app)->cur_url = String ();
 }
 
 gboolean cb_mainview_delete (GtkObject *, GdkEvent *, Application *app) {
