@@ -544,14 +544,16 @@ KDE_NO_EXPORT void ElementPrivate::clear () {
     params.clear ();
 }
 
-Element::Element (NodePtr & d, short id)
-    : Node (d, id), d (new ElementPrivate) {}
+Element::Element (NodePtr &doc, short id)
+    : Node (doc, id), d (NULL) {}
 
 Element::~Element () {
     delete d;
 }
 
 void Element::setParam (const TrieString &name, const String &val, int *mid) {
+    if (!d)
+        d = new ElementPrivate;
     ParamValue * pv = d->params [name];
     if (!pv) {
         pv = new ParamValue (mid ? getAttribute (name) : val);
@@ -573,33 +575,38 @@ void Element::setParam (const TrieString &name, const String &val, int *mid) {
 }
 
 String Element::param (const TrieString & name) {
-    ParamValue * pv = d->params [name];
-    if (pv)
-        return pv->value ();
+    if (d) {
+        ParamValue * pv = d->params [name];
+        if (pv)
+            return pv->value ();
+    }
     return getAttribute (name);
 }
 
 void Element::resetParam (const TrieString &name, int mid) {
-    ParamValue * pv = d->params [name];
-    if (pv && pv->modifications) {
-        if (int (pv->modifications->size ()) > mid && mid > -1) {
-            (*pv->modifications) [mid].clear ();
-            while (pv->modifications->size () > 0 &&
-                    pv->modifications->back ().isNull ())
-                pv->modifications->pop_back ();
-        }
-        String val = pv->value ();
-        if (pv->modifications->size () == 0) {
-            delete pv->modifications;
-            pv->modifications = 0L;
-            if (val.isNull ()) {
-                delete pv;
-                d->params.erase (name);
+    if (d) {
+        ParamValue * pv = d->params [name];
+        if (pv && pv->modifications) {
+            if (int (pv->modifications->size ()) > mid && mid > -1) {
+                (*pv->modifications) [mid].clear ();
+                while (pv->modifications->size () > 0 &&
+                        pv->modifications->back ().isNull ())
+                    pv->modifications->pop_back ();
             }
+            String val = pv->value ();
+            if (pv->modifications->size () == 0) {
+                delete pv->modifications;
+                pv->modifications = 0L;
+                if (val.isNull ()) {
+                    delete pv;
+                    d->params.erase (name);
+                }
+            }
+            parseParam (name, val);
+            return;
         }
-        parseParam (name, val);
-    } else
-        errorLog () << "resetting " << name.toString() << " that doesn't exists" << endl;
+    }
+    errorLog () << "resetting " << name.toString() << " that doesn't exists" << endl;
 }
 
 void Element::setAttribute (const TrieString & name, const String & value) {
@@ -623,7 +630,8 @@ String Element::getAttribute (const TrieString & name) {
 }
 
 void Element::init () {
-    d->clear();
+    if (d)
+        d->clear();
     for (Attribute *a = attributes ().first (); a; a = a->nextSibling ()) {
         String v = a->value ();
         int p = v.indexOf (Char ('{'));
@@ -637,13 +645,15 @@ void Element::init () {
 }
 
 void Element::reset () {
-    d->clear();
+    if (d)
+        d->clear();
     Node::reset ();
 }
 
 void Element::clear () {
     m_attributes = AttributeList (); // remove attributes
-    d->clear();
+    if (d)
+        d->clear();
     Node::clear ();
 }
 
