@@ -670,7 +670,6 @@ void MPlayer::toggleScale ()
 KMPLAYER_NO_EXPORT void MPlayer::processExited (UnixProcess *) {
     unix_process.closeStdOut ();
     commands.clear ();
-    debugLog() << "processExited restart " << needs_restarted << endl;
     if (needs_restarted) {
         int pos = m_position;
         play (m_mrl);
@@ -719,7 +718,8 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
             if (!c)
                 c = strstr (tok, "V:");
             if (c) {
-                setPosition ((int)(10 * strtof (c + 2, 0L)));
+                if (request_seek == NO_SEEK)
+                    setPosition ((int)(10 * strtof (c + 2, 0L)));
                 request_seek = NO_SEEK;
                 if (Playing == m_transition_state)
                     m_transition_state = NotRunning;
