@@ -73,6 +73,7 @@ public:// slots:
     virtual bool hue (int pos, bool absolute);
     virtual bool contrast (int pos, bool absolute);
     virtual bool brightness (int pos, bool absolute);
+    virtual void toggleScale ();
     KMPLAYER_NO_EXPORT const char * name () { return m_name; }
     void scheduledStateChanged ();
     ProcessNotify * processNotify () { return m_notify; }
@@ -181,11 +182,13 @@ public:
     virtual bool hue (int pos, bool absolute);
     virtual bool contrast (int pos, bool absolute);
     virtual bool brightness (int pos, bool absolute);
+    virtual void toggleScale ();
 
     void setPlayer (const char *p) { path = p; }
     void setAudioDriver (const char *ao) { audio_driver = ao; }
     void setVideoDriver (const char *vo) { video_driver = vo; }
     void setAutoSubTitles (bool b) { auto_sub_titles = b; }
+    void setSupportsPanzoom (bool b) { supports_panzoom = b; }
 
     // for UnixProcessListener functions
     void processExited (UnixProcess *);
@@ -195,18 +198,23 @@ public:
 protected:
     bool sendCommand (const String &);
     bool removeQueued (const char *cmd);
+    bool calculateScale (int &x, int &y, int &w, int &h);
     typedef std::list <String> StringList;
     StringList commands;
     String command_chunk;
     UnixProcess unix_process;
     int request_seek;
+    int stream_width;
+    int stream_height;
     const char *path;
     const char *audio_driver;
     const char *video_driver;
     State m_transition_state;
     bool request_quit;
     bool auto_sub_titles;
-    bool padding;
+    bool supports_panzoom;
+    bool panzoom_enabled;
+    bool needs_restarted;
     char outbuf[512];
 };
 
