@@ -1804,7 +1804,8 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (Application *app)
    m_fullscreen (false),
    m_event_filter_on (false),
    m_updaters_enabled (true),
-   m_video_filter (true) {
+   m_video_filter (true),
+   m_use_aspects (true) {
 }
 
 KDE_NO_CDTOR_EXPORT ViewArea::~ViewArea () {
@@ -1817,6 +1818,7 @@ KDE_NO_EXPORT void ViewArea::reset () {
         g_source_remove (m_repaint_timer);
     m_repaint_timer = 0;
     aspect = 0,0;
+    m_use_aspects = true;
 }
 
 KDE_NO_EXPORT void ViewArea::mousePressEvent (int x, int y) {
@@ -1904,7 +1906,7 @@ KDE_NO_EXPORT void ViewArea::deleteEvent () {
 KDE_NO_EXPORT
 void ViewArea::setAudioVideoGeometry (const IRect &rect, unsigned int * bg_color) {
     int x = rect.x (), y = rect.y (), w = rect.width (), h = rect.height ();
-    if (!surface->node && aspect > 0.01) {
+    if (m_use_aspects && !surface->node && aspect > 0.01) {
         int w1 = w;
         int h1 = h;
         w = int (h * aspect);
